
[![Enterprise Modules](https://raw.githubusercontent.com/enterprisemodules/public_images/master/banner1.jpg)](https://www.enterprisemodules.com)

#### Table of Contents

1. [Overview](#overview)
2. [License](#license)
3. [Description - What the module does and why it is useful](#description)
4. [Setup](#setup)
  * [Requirements](#requirements)
  * [Installing the iib_config module](#installing-the-iib_config-module)
5. [Usage - Configuration options and additional functionality](#usage)
6. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
7. [Limitations - OS compatibility, etc.](#limitations)

## Overview

This module allows you to configure IBM Integration Bus (IIB) software. It is part of our family of Puppet modules to install and manage IBM messaging middleware. Besides the [`iib_config`](https://www.enterprisemodules.com/shop/products/ibm-iib-config) module, this family also contains:

- [`mq_install`](https://www.enterprisemodules.com/shop/products/ibm-mq-install) to install the MQ software.
- [`mq_config`](https://www.enterprisemodules.com/shop/products/ibm-mq-config) to configure and manage the MQ software
- [`iib_install`](https://www.enterprisemodules.com/shop/products/ibm-iib-install) to install the IBM Integration Bus software

## License

This is a commercially licensed module. But you can use the module on VirtualBox based development systems for **FREE**. When used on **real** systems a license is required.

You can license our modules in multiple ways. Our basic licensing model requires a subscription per node. But [contact](https://www.enterprisemodules.com/company/contact/) us for details.

Check the [License](https://forge.puppet.com/enterprisemodules/iib_config/license) for details.

## Description

Our `iib_config` module allows you to configure and manage almost everything you'd want to manage on of an IBM Integration Bus installations. The module allows you to manage:

- iib_broker (or node)
- iib_deployment
- iib_instance
- iib_server
- iib_propery (Manages every kind of propert on a Broker or a Server)

Here is example puppet code to manage a IIB server:

```puppet
iib_server { 'iib8/NODE1/server_2':
  ensure                                                  => 'present',
  callable_flow_manager_delay_reply_until_flow_commit     => 'false',
  callable_flow_manager_disable_remote_input_registration => 'false',
  callable_flow_manager_redeploy_message_timeout          => '5',
  callable_flow_manager_remote_retry_timeout              => '60',
  callable_flow_manager_retry_local_during_deploy         => 'true',
  callable_flow_manager_retry_remote_until_timeout        => 'true',
  callable_flow_manager_vrmf_introduced_at                => '10.0.0.4',
  connectors_shared_idle_timeout                          => '60',
  execution_group_http_nodes_embedded_listener            => 'false',
  execution_group_injection_mode                          => 'Disabled',
  execution_group_soap_nodes_embedded_listener            => 'true',
  execution_group_trace_filter                            => 'none',
  execution_group_trace_level                             => 'none',
  execution_group_user_trace_filter                       => 'none',
  http_connector_cors_enabled                             => 'false',
  http_connector_max_keep_alive_requests                  => '0',
  http_connector_port                                     => '7801',
  http_connector_tcp_no_delay                             => 'true',
  http_connector_user_trace_level                         => 'none',
  https_connector_cors_enabled                            => 'false',
  https_connector_max_keep_alive_requests                 => '0',
  https_connector_port                                    => '0',
  https_connector_tcp_no_delay                            => 'true',
  https_connector_user_trace_level                        => 'none',
  rest_resource_stats_reporting_on                        => 'inactive',
  status                                                  => 'running',
}
```

Check [here](https://www.enterprisemodules.com/docs/iib_config/description.html) to see the full documentation for this module.


## Setup

### Requirements

The [`iib_config`](https://www.enterprisemodules.com/shop/products/puppet-iib_config-module) module requires:

- Puppet module [`enterprisemodules-easy_type`](https://forge.puppet.com/enterprisemodules/easy_type) installed.
- Puppet version 4.9 or higher. Can be Puppet Enterprise or Puppet Open Source
- IBM IIB 10 installation. All fixpacks supported.
- A valid License from IBM to use this software.
- A valid entitlement for usage of this module by Enterprise Modules.
- Runs on most Linux systems.
- Windows systems are **NOT** supported

### Installing the iib_config module

To install these modules, you can use a `Puppetfile`

```
mod 'enterprisemodules/iib_config'               ,'1.0.x'
```

Then use the `librarian-puppet` or `r10K` to install the software.

You can also install the software using the `puppet module`  command:

```
puppet module install enterprisemodules-iib_config
```

## Usage

Building a total IIB setup requires quite some work. To help you, we have built some examples:
- [IIB only example](https://github.com/enterprisemodules/simple_iib_demo)
- [MQ and IIB example](https://github.com/enterprisemodules/simple_mqiib_demo)

Thes repos contain examples of how you can install and configure a basic IIB setup.

## Reference

Here you can find some more information regarding this puppet module:

- [The documentation](https://www.enterprisemodules.com/docs/iib_config/description.html)
- [The product announcement](https://www.enterprisemodules.com/news/2017/05/IBM-modules-with-virtualsciences/)

Here is a related blog posts:
- [Introducing the IBM information Bus Puppet modules.](https://www.enterprisemodules.com/blog/2017/09/introducing-iib-modules/)

Some example code:
- [Simple IIB demo](https://github.com/enterprisemodules/simple_iib_demo)


## Limitations

This module runs most Linux versions. It requires a puppet version higher than 4. The module does **NOT** run on windows systems. Contact us of you need to run this module on other flovors of UNIX. We can work together with you to make it work.
