---
title: iib broker
keywords: documentation
layout: documentation
sidebar: iib_config_sidebar
toc: false
---
## Overview

This resource allows you to manage broker in an IBM IIB realm.

Here is an example on how you should use this:

    iib_broker { 'IIB107/IB10NODE1':
      ensure => 'present',
      status => 'running',
    }

In this example you are ensuring that broker is running. If the server is
stopped the resource starts broker, if broker is absent then new is created.

Valid managable global node component names:
- userLilPath
- configurationChangeTimeout
- internalConfigurationTimeout
- httpListenerPort
- statisticsMajorInterval
- ldapPrincipal
- ldapCredentials
- ICU converter path
- userExitPath
- activeUserExits
- function level
- security_status
- cachePolicy
- cachePortRange
- integrationRegistryHostname

## Attributes



Attribute Name                                                                       | Short Description                                                                                      |
------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------ |
[active_user_exits](#iib_broker_active_user_exits)                                   | This property allows you to manage activeUserExits of iib broker in an IBM IIB realm.                  |
[admin_url](#iib_broker_admin_url)                                                   | This property allows you to manage set admin_url of iib_broker in an IBM IIB realm.                    |
[auto_restart](#iib_broker_auto_restart)                                             | a value is changes that can only be applied on a stopped broker.                                       |
[broker](#iib_broker_broker)                                                         | This parameter specifies custom name for iib_broker in IBM IIB realm.                                  |
[broker_keystore_file](#iib_broker_broker_keystore_file)                             | This property allows you to manage brokerKeystoreFile of iib broker in an IBM IIB realm.               |
[broker_truststore_file](#iib_broker_broker_truststore_file)                         | This property allows you to manage brokerTruststoreFile of iib broker in an IBM IIB realm.             |
[cache_policy](#iib_broker_cache_policy)                                             | This property allows you to manage cachePolicy of iib broker in an IBM IIB realm.                      |
[cache_port_range](#iib_broker_cache_port_range)                                     | This property allows you to manage cachePortRange of iib broker in an IBM IIB realm.                   |
[configuration_change_timeout](#iib_broker_configuration_change_timeout)             | This property allows you to manage configurationChangeTimeout of iib broker in an IBM IIB realm.       |
[ensure](#iib_broker_ensure)                                                         | The basic property that the resource should be in.                                                     |
[function_level](#iib_broker_function_level)                                         | This property allows you to manage the function level of iib broker in an IBM IIB realm.               |
[http_listener_allow_ssl_v3](#iib_broker_http_listener_allow_ssl_v3)                 | This property allows you to manage allowSSLv3 of iib broker httplistener in an IBM IIB realm.          |
[http_listener_enable_ssl_connector](#iib_broker_http_listener_enable_ssl_connector) | This property allows you to manage enableSSLConnector of iib broker httplistener in an IBM IIB realm.  |
[http_listener_java_debug_port](#iib_broker_http_listener_java_debug_port)           | This property allows you to manage javaDebugPort of iib broker httplistener in an IBM IIB realm.       |
[http_listener_http_connector_port](#iib_broker_http_listener_http_connector_port)                                 | This property allows you to manage httpListenerPort of iib broker in an IBM IIB realm.                 |
[http_listener_start_listener](#iib_broker_http_listener_start_listener)             | This property allows you to manage startListener of iib broker httplistener in an IBM IIB realm.       |
[http_listener_thread_pool_size](#iib_broker_http_listener_thread_pool_size)         | This property allows you to manage threadPoolSize of iib broker httplistener in an IBM IIB realm.      |
[http_listener_trace_level](#iib_broker_http_listener_trace_level)                   | This property allows you to manage traceLevel of iib broker httplistener in an IBM IIB realm.          |
[http_listener_trace_override_level](#iib_broker_http_listener_trace_override_level) | This property allows you to manage traceOverrideLevel of iib broker httplistener in an IBM IIB realm.  |
[http_listener_trace_override_size](#iib_broker_http_listener_trace_override_size)   | This property allows you to manage traceOverrideSize of iib broker httplistener in an IBM IIB realm.   |
[https_connector_keystore_file](#iib_broker_https_connector_keystore_file)           | This property allows you to manage keystoreFile of iib broker in an IBM IIB realm.                     |
[https_connector_keystore_pass](#iib_broker_https_connector_keystore_pass)           | This property allows you to manage keystorePass of iib broker in an IBM IIB realm.                     |
[icu_converter_path](#iib_broker_icu_converter_path)                                 | This property allows you to manage ICU converter path of iib broker in an IBM IIB realm.               |
[instance](#iib_broker_instance)                                                     | This shared parameter specifies iib_instance in IBM IIB realm.                                         |
[integration_registry_hostname](#iib_broker_integration_registry_hostname)           | This property allows you to manage integrationRegistryHostname of iib broker in an IBM IIB realm.      |
[internal_configuration_timeout](#iib_broker_internal_configuration_timeout)         | This property allows you to manage internalConfigurationTimeout of iib broker in an IBM IIB realm.     |
[ldap_credentials](#iib_broker_ldap_credentials)                                     | This property allows you to manage ldapCredentials of iib broker in an IBM IIB realm.                  |
[ldap_principal](#iib_broker_ldap_principal)                                         | This property allows you to manage ldapPrincipal of iib broker in an IBM IIB realm.                    |
[name](#iib_broker_name)                                                             | This parameter specifies uniqe custom name for iib_broker in Puppet realm.                             |
[provider](#iib_broker_provider)                                                     | resource.                                                                                              |
[queue_manager](#iib_broker_queue_manager)                                           | This property allows you to manage set queue manager of iib_broker in an IBM IIB realm.                |
[security_cache_sweep_interval](#iib_broker_security_cache_sweep_interval)           | This property allows you to manage cacheSweepInterval of iib broker SecurityCache in an IBM IIB realm. |
[security_cache_timeout](#iib_broker_security_cache_timeout)                         | This property allows you to manage cacheTimeout of iib broker SecurityCache in an IBM IIB realm.       |
[security_status](#iib_broker_security_status)                                       | This property allows you to manage Administration security of iib broker in an IBM IIB realm.          |
[service_federation_scmp_enable_ssl](#iib_broker_service_federation_scmp_enable_ssl) | This property allows you to manage enabled of iib broker scmp in an IBM IIB realm.                     |
[service_federation_scmp_enabled](#iib_broker_service_federation_scmp_enabled)       | This property allows you to manage cacheSweepInterval of iib broker scmp in an IBM IIB realm.          |
[statistics_major_interval](#iib_broker_statistics_major_interval)                   | This property allows you to manage statisticsMajorInterval of iib broker in an IBM IIB realm.          |
[status](#iib_broker_status)                                                         | The status of the IIB node.                                                                            |
[user_exit_path](#iib_broker_user_exit_path)                                         | This property allows you to manage userExitPath of iib broker in an IBM IIB realm.                     |
[user_lil_path](#iib_broker_user_lil_path)                                           | This property allows you to manage userLilPath of iib broker in an IBM IIB realm.                      |




### active_user_exits<a name='iib_broker_active_user_exits'>

This property allows you to manage activeUserExits of iib broker in an IBM IIB realm.

A change in this property can only be done by stopping the broker. By default puppet
will not do this and issue a warning. When you want to apply this value anyway, use
the `auto_restart` parameter and set it to`true`.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ...
      active_user_exits  => 'none',
      auto_restart       =>  true,
      ...
    }

In this example you a changte the component value activeUserExits of IBM IIB broker
and set it to to `none`.



[Back to overview of iib_broker](#attributes)

### admin_url<a name='iib_broker_admin_url'>

This property allows you to manage set admin_url of iib_broker in an IBM IIB realm.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ensure    => 'present',
      admin_url => 'http://iib01.newurl.com:4414',
      status    => 'stopped',
    }

In this example you are ensuring that broker is present and is stopped. Then
change component value admin_url of IBM IIB broker to
`http://iib01.newurl.com:4414`.

Valid values

- Url string



[Back to overview of iib_broker](#attributes)

### auto_restart<a name='iib_broker_auto_restart'>

Specfies if you want to automaticaly want to stop and start the broker if
a value is changes that can only be applied on a stopped broker.

When you speciefied a `true` value here and Puppet detects a requested change on
a property that needs a stopped broker, , Puppet will stop the broker, apply the
requested value and start the broker again.

If you specify a `false` value, Puppet will not touch the state of the broker and
just ignore the value.

Valid values are `true`, `false`.

[Back to overview of iib_broker](#attributes)

### broker<a name='iib_broker_broker'>

This parameter specifies custom name for iib_broker in IBM IIB realm.

In example

    'NODE1'



[Back to overview of iib_broker](#attributes)

### broker_keystore_file<a name='iib_broker_broker_keystore_file'>

This property allows you to manage brokerKeystoreFile of iib broker in an IBM IIB realm.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ensure                       => 'present',
      broker_keystore_file         => '/app/mib/ssl/key.jks',
      status                       => 'running',
    }



[Back to overview of iib_broker](#attributes)

### broker_truststore_file<a name='iib_broker_broker_truststore_file'>

This property allows you to manage brokerTruststoreFile of iib broker in an IBM IIB realm.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ensure                       => 'present',
      broker_truststore_file       => '/app/mib/ssl/key.jks',
      status                       => 'running',
    }



[Back to overview of iib_broker](#attributes)

### cache_policy<a name='iib_broker_cache_policy'>

This property allows you to manage cachePolicy of iib broker in an IBM IIB realm.

A change in this property can only be done by stopping the broker. By default puppet
will not do this and issue a warning. When you want to apply this value anyway, use
the `auto_restart` parameter and set it to`true`.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ...
      cache_policy => 'none',
      auto_restart =>  true,
      ...
    }

In this example you a change the component value cachePolicy of IBM IIB broker
and set it to to `none`.

Valid values

- string



[Back to overview of iib_broker](#attributes)

### cache_port_range<a name='iib_broker_cache_port_range'>

This property allows you to manage cachePortRange of iib broker in an IBM IIB realm.

A change in this property can only be done by stopping the broker. By default puppet
will not do this and issue a warning. When you want to apply this value anyway, use
the `auto_restart` parameter and set it to`true`.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ...
      cache_port_range => '2820-2880',
      auto_restart     =>  true,
      ...
    }

In this example you a change the component value cachePortRange of IBM IIB broker
and set it to a range from `2820` to `2880`.

Valid values

- port range



[Back to overview of iib_broker](#attributes)

### configuration_change_timeout<a name='iib_broker_configuration_change_timeout'>

This property allows you to manage configurationChangeTimeout of iib broker in an IBM IIB realm.

A change in this property can only be done by stopping the broker. By default puppet
will not do this and issue a warning. When you want to apply this value anyway, use
the `auto_restart` parameter and set it to`true`.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ...
      configuration_change_timeout => '40',
      auto_restart                 =>  true,
      ...
    }

In this example you a change the component value configurationChangeTimeout of IBM IIB broker
and set it to a value of `40`.

Valid values

- integer



[Back to overview of iib_broker](#attributes)

### ensure<a name='iib_broker_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`.

[Back to overview of iib_broker](#attributes)

### function_level<a name='iib_broker_function_level'>

This property allows you to manage the function level of iib broker in an IBM IIB realm.

A change in this property can only be done by stopping the broker. By default puppet
will not do this and issue a warning. When you want to apply this value anyway, use
the `auto_restart` parameter and set it to`true`.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ...
      function_level => '10.0.0.7',
      auto_restart   =>  true,
      ...
    }

In this example you a change the function levelof the IIB broker to IIB version
10.0.0.7.

Valid values

- string



[Back to overview of iib_broker](#attributes)

### http_listener_allow_ssl_v3<a name='iib_broker_http_listener_allow_ssl_v3'>

This property allows you to manage allowSSLv3 of iib broker httplistener in an IBM IIB realm.

When applying this manifest make sure that broker is running.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ensure                     => 'present',
      http_listener_allow_ssl_v3 => 'true',
      status                     => 'running',
    }

In this example you are ensuring that broker is present and is stopped. Then
change component property value allowSSLv3 of IBM IIB broker to `true`
seconds.

Valid values are `true`, `false`.

[Back to overview of iib_broker](#attributes)

### http_listener_enable_ssl_connector<a name='iib_broker_http_listener_enable_ssl_connector'>

This property allows you to manage enableSSLConnector of iib broker httplistener in an IBM IIB realm.

When applying this manifest make sure that broker is running.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ensure                             => 'present',
      http_listener_enable_ssl_connector => 'true',
      status                             => 'running',
    }

In this example you are ensuring that broker is present and is stopped. Then
change component property value enableSSLConnector of IBM IIB broker to `true`
seconds.

Valid values are `true`, `false`.

[Back to overview of iib_broker](#attributes)

### http_listener_java_debug_port<a name='iib_broker_http_listener_java_debug_port'>

This property allows you to manage javaDebugPort of iib broker httplistener in an IBM IIB realm.

When applying this manifest make sure that broker is running.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ensure                        => 'present',
      http_listener_java_debug_port => '9101',
      status                        => 'running',
    }

In this example you are ensuring that broker is present and is running. Then
change component property value javaDebugPort of IBM IIB broker to `true`
seconds.



[Back to overview of iib_broker](#attributes)

### http_listener_http_connector_port<a name='iib_broker_http_listener_http_connector_port'>

This property allows you to manage httpListenerPort of iib broker in an IBM IIB realm.

A change in this property can only be done by stopping the broker. By default puppet
will not do this and issue a warning. When you want to apply this value anyway, use
the `auto_restart` parameter and set it to`true`.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ...
      http_listener_http_connector_port => '7490',
      auto_restart       =>  true,
      ...
    }

In this example you a change the component value httpListenerPort of IBM IIB broker
and set it to a value of `7490`.

Valid values

- port number



[Back to overview of iib_broker](#attributes)

### http_listener_start_listener<a name='iib_broker_http_listener_start_listener'>

This property allows you to manage startListener of iib broker httplistener in an IBM IIB realm.

When applying this manifest make sure that broker is running.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ensure                       => 'present',
      http_listener_start_listener => 'true',
      status                       => 'running',
    }

In this example you are ensuring that broker is present and is running. Then
change component property value startListener of IBM IIB broker to `true`
seconds.

Valid values are `true`, `false`.

[Back to overview of iib_broker](#attributes)

### http_listener_thread_pool_size<a name='iib_broker_http_listener_thread_pool_size'>

This property allows you to manage threadPoolSize of iib broker httplistener in an IBM IIB realm.

When applying this manifest make sure that broker is running.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ensure                         => 'present',
      http_listener_thread_pool_size => '100',
      status                         => 'running',
    }

In this example you are ensuring that broker is present and is running. Then
change component property value threadPoolSize of IBM IIB broker to `true`
seconds.



[Back to overview of iib_broker](#attributes)

### http_listener_trace_level<a name='iib_broker_http_listener_trace_level'>

This property allows you to manage traceLevel of iib broker httplistener in an IBM IIB realm.

When applying this manifest make sure that broker is running.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ensure                    => 'present',
      http_listener_trace_level => 'debug',
      status                    => 'running',
    }

In this example you are ensuring that broker is present and is runningz. Then
change component property value traceLevel of IBM IIB broker to `true`
seconds.

Valid values are `none`, `trace`, `debugTrace`.

[Back to overview of iib_broker](#attributes)

### http_listener_trace_override_level<a name='iib_broker_http_listener_trace_override_level'>

This property allows you to manage traceOverrideLevel of iib broker httplistener in an IBM IIB realm.

When applying this manifest make sure that broker is running.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ensure                             => 'present',
      http_listener_trace_override_level => 'debug',
      status                             => 'running',
    }

In this example you are ensuring that broker is present and is running. Then
change component property value traceOverrideLevel of IBM IIB broker to `true`
seconds.

Valid values are `none`, `trace`, `debugTrace`.

[Back to overview of iib_broker](#attributes)

### http_listener_trace_override_size<a name='iib_broker_http_listener_trace_override_size'>

This property allows you to manage traceOverrideSize of iib broker httplistener in an IBM IIB realm.

When applying this manifest make sure that broker is running.

Here is an example on how you should use this:

  iib_broker { 'iib8/NODE1':
    ensure                            => 'present',
    http_listener_trace_override_size => '100',
    status                            => 'running',
  }

In this example you are ensuring that broker is present and is running. Then
change component property value traceOverrideSize of IBM IIB broker to `true`
seconds.



[Back to overview of iib_broker](#attributes)

### https_connector_keystore_file<a name='iib_broker_https_connector_keystore_file'>

This property allows you to manage keystoreFile of iib broker in an IBM IIB realm.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ensure                       => 'present',
      keystore_file                => '/app/mib/ssl/key.jks',
      status                       => 'running',
    }



[Back to overview of iib_broker](#attributes)

### https_connector_keystore_pass<a name='iib_broker_https_connector_keystore_pass'>

This property allows you to manage keystorePass of iib broker in an IBM IIB realm.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ensure                       => 'present',
      keystore_pass                => 'pass',
      status                       => 'running',
    }



[Back to overview of iib_broker](#attributes)

### icu_converter_path<a name='iib_broker_icu_converter_path'>

This property allows you to manage ICU converter path of iib broker in an IBM IIB realm.

A change in this property can only be done by stopping the broker. By default puppet
will not do this and issue a warning. When you want to apply this value anyway, use
the `auto_restart` parameter and set it to`true`.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ...
      icu_converter_path => '/path',
      auto_restart       =>  true,
      ...
    }

In this example you a change the component value ICU converter path of IBM IIB broker to
`/path`.

Valid values:

- string with path



[Back to overview of iib_broker](#attributes)

### instance<a name='iib_broker_instance'>

This shared parameter specifies iib_instance in IBM IIB realm.

Example name

    'iib8'



[Back to overview of iib_broker](#attributes)

### integration_registry_hostname<a name='iib_broker_integration_registry_hostname'>

This property allows you to manage integrationRegistryHostname of iib broker in an IBM IIB realm.

A change in this property can only be done by stopping the broker. By default puppet
will not do this and issue a warning. When you want to apply this value anyway, use
the `auto_restart` parameter and set it to`true`.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ...
      integration_registry_hostname => 'myhostname.example.org',
      auto_restart                  =>  true,
      ...
    }

In this example you a change the component integrationRegistryHostname of IBM IIB broker to
`myhostname.example.org` of IBM IIB broker.

Valid values

- a host name



[Back to overview of iib_broker](#attributes)

### internal_configuration_timeout<a name='iib_broker_internal_configuration_timeout'>

This property allows you to manage internalConfigurationTimeout of iib broker in an IBM IIB realm.

A change in this property can only be done by stopping the broker. By default puppet
will not do this and issue a warning. When you want to apply this value anyway, use
the `auto_restart` parameter and set it to`true`.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ...
      internal_configuration_timeout => '100',
      auto_restart                   =>  true,
      ...
    }

In this example you a change the component internalConfigurationTimeout of IBM IIB broker to
`100`.

Valid values

- integer



[Back to overview of iib_broker](#attributes)

### ldap_credentials<a name='iib_broker_ldap_credentials'>

This property allows you to manage ldapCredentials of iib broker in an IBM IIB realm.

A change in this property can only be done by stopping the broker. By default puppet
will not do this and issue a warning. When you want to apply this value anyway, use
the `auto_restart` parameter and set it to`true`.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ...
      ldap_credentials => 'verysecret',
      auto_restart     =>  true,
      ...
    }

In this example you a change the component value ldapCredentials of IBM IIB broker
and set it to a value of `verysecret`.

Valid values

- string



[Back to overview of iib_broker](#attributes)

### ldap_principal<a name='iib_broker_ldap_principal'>

This property allows you to manage ldapPrincipal of iib broker in an IBM IIB realm.

A change in this property can only be done by stopping the broker. By default puppet
will not do this and issue a warning. When you want to apply this value anyway, use
the `auto_restart` parameter and set it to`true`.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ...
      ldap_principal => 'cn=admin,ou=example,ou=com',
      auto_restart   =>  true,
      ...
    }

In this example you a change the component value ldapPrincipal of IBM IIB broker
and set it to a value of `cn=admin,ou=example,ou=com`.

Valid values

- string



[Back to overview of iib_broker](#attributes)

### name<a name='iib_broker_name'>

This parameter specifies uniqe custom name for iib_broker in Puppet realm.

In example

    'iib8/NODE1'



[Back to overview of iib_broker](#attributes)

### provider<a name='iib_broker_provider'>

The specific backend to use for this `iib_broker`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage IIB Brokers



[Back to overview of iib_broker](#attributes)

### queue_manager<a name='iib_broker_queue_manager'>

This property allows you to manage set queue manager of iib_broker in an IBM IIB realm.

You can set queue_manager only at the creation on iib_broker.

Here is an example on how you should use this:


    iib_broker { 'iib8/NODE1':
      ensure        => 'present',
      queue_manager => 'MQQM1'
    }


In this example you are setting the queue manager property of iib_broker. The
broker at the creation manifest.



[Back to overview of iib_broker](#attributes)

### security_cache_sweep_interval<a name='iib_broker_security_cache_sweep_interval'>

This property allows you to manage cacheSweepInterval of iib broker SecurityCache in an IBM IIB realm.

When applying this manifest make sure that broker is running.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ensure                        => 'present',
      security_cache_sweep_interval => '600',
      status                        => 'running',
    }

In this example you are ensuring that broker is present and is stopped. Then
change component property value cacheSweepInterval of IBM IIB broker
SecurityCache to `600` seconds.



[Back to overview of iib_broker](#attributes)

### security_cache_timeout<a name='iib_broker_security_cache_timeout'>

This property allows you to manage cacheTimeout of iib broker SecurityCache in an IBM IIB realm.

When applying this manifest make sure that broker is running.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ensure                 => 'present',
      security_cache_timeout => '600',
      status                 => 'running',
    }

In this example you are ensuring that broker is present and is stopped. Then
change component property value cacheTimeout of IBM IIB broker SecurityCache to `600`
seconds.



[Back to overview of iib_broker](#attributes)

### security_status<a name='iib_broker_security_status'>

This property allows you to manage Administration security of iib broker in an IBM IIB realm.

When applying this manifest make sure that broker is stopped.

A change in this property can only be done by stopping the broker. By default puppet
will not do this and issue a warning. When you want to apply this value anyway, use
the `auto_restart` parameter and set it to`true`.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ...
      security_status  => 'inactive',
      auto_restart     =>  true,
      ...
    }

In this example you a change the component value Administration security of IBM IIB broker
and set it to a value of `inactive`.

Valid values

- active
- inactive

Valid values are `active`, `inactive`.

[Back to overview of iib_broker](#attributes)

### service_federation_scmp_enable_ssl<a name='iib_broker_service_federation_scmp_enable_ssl'>

This property allows you to manage enabled of iib broker scmp in an IBM IIB realm.

When applying this manifest make sure that broker is running.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ensure                             => 'present',
      service_federation_scmp_enable_ssl => 'true',
      status                             => 'running',
    }

In this example you are ensuring that broker is present and is stopped. Then
change component property value enabled of IBM IIB broker scmp to `true`
seconds.

Valid values are `true`, `false`.

[Back to overview of iib_broker](#attributes)

### service_federation_scmp_enabled<a name='iib_broker_service_federation_scmp_enabled'>

This property allows you to manage cacheSweepInterval of iib broker scmp in an IBM IIB realm.

When applying this manifest make sure that broker is running.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ensure                          => 'present',
      service_federation_scmp_enabled => 'true',
      status                          => 'running',
    }

In this example you are ensuring that broker is present and is stopped. Then
change component property value enabled of IBM IIB broker scmp to `true`
seconds.

Valid values are `true`, `false`.

[Back to overview of iib_broker](#attributes)

### statistics_major_interval<a name='iib_broker_statistics_major_interval'>

This property allows you to manage statisticsMajorInterval of iib broker in an IBM IIB realm.

A change in this property can only be done by stopping the broker. By default puppet
will not do this and issue a warning. When you want to apply this value anyway, use
the `auto_restart` parameter and set it to`true`.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ...
      statistics_major_interval => 200,
      auto_restart              =>  true,
      ...
    }

In this example you a change the component value statisticsMajorInterval of IBM IIB broker
and set it to a value of `200`.

Valid values

- integer



[Back to overview of iib_broker](#attributes)

### status<a name='iib_broker_status'>

The status of the IIB node. Can either be `running` or `stopped`.

Here is an example on how to use this:

    iib_node {...
      ...
      status => 'running',
      ...
    }

Valid values are `stopped`, `running`.

[Back to overview of iib_broker](#attributes)

### user_exit_path<a name='iib_broker_user_exit_path'>

This property allows you to manage userExitPath of iib broker in an IBM IIB realm.

A change in this property can only be done by stopping the broker. By default puppet
will not do this and issue a warning. When you want to apply this value anyway, use
the `auto_restart` parameter and set it to`true`.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ...
      user_exit_path => '/path',
      auto_restart   =>  true,
      ...
    }

In this example you a change the component value userExitPath of IBM IIB broker
and set it to a value of `/path`.

Valid values

- string



[Back to overview of iib_broker](#attributes)

### user_lil_path<a name='iib_broker_user_lil_path'>

This property allows you to manage userLilPath of iib broker in an IBM IIB realm.

    iib_broker { 'iib8/NODE1':
      ...
      user_exit_path => '/path',
      auto_restart   =>  true,
      ...
    }

In this example you a change the component value userLilPath of IBM IIB broker
and set it to a value of `/path`.

Valid values

- string



[Back to overview of iib_broker](#attributes)
