---
title: iib property
keywords: documentation
layout: documentation
sidebar: iib_config_sidebar
toc: false
---
## Overview

This resource allows you to manage brokers and servers in an IBM IIB realm.

This type can be used to construct `mqsichangebroker` or `mqsichangeproperties`
commands for you setup. This type is a fallback for when the property is not
(yet) support on `iib_broker` or `iib_server`. Use this type with care.

Here is an example on how to write manifest for global node component value
changing:

    iib_property {'set_node_cache_policy':
      scope     => 'iib8/NODE1',
      component => 'cachePolicy',
      restart   => true,
      set_value => 'none'
    }


Valid global node component names:
- userLilPath
- configurationChangeTimeout
- internalConfigurationTimeout
- httpListenerPort
- statisticsMajorInterval
- ldapPrincipal
- ldapCredentials
- ICU converter path
- userExitPath
- activeUserExits
- function level
- security_status
- cachePolicy
- cachePortRange
- integrationRegistryHostname

Here is an example on how to write manifest for node component that takes
objectName:

    iib_property {'set_node_cache_policy':
      scope            => 'iib8/NODE1',
      component        => 'webadmins',
      object_name      => 'HTTPConnector',
      object_property  => 'compression',
      restart          => false,
      set_value        => 'on'
    }

Make sure that selected node is running before applying manifest.

Valid node component names that take objectName:
- httplistener
- securitycache
- cachemanager
- webadmin
- crlFile

Here is an example on how to write manifest for server property
changing:

    iib_property {'set_server_accept_count_to_200':
      scope       => 'iib8/NODE1/server_1',
      component   => 'HTTPConnector',
      object_name => 'acceptCount',
      restart     => false,
      set_value   => '200'
    }

## Attributes



Attribute Name                                   | Short Description                                                            |
------------------------------------------------ | ---------------------------------------------------------------------------- |
[component](#iib_property_component)             | want to manage.                                                              |
[name](#iib_property_name)                       | This parameter specifies uniqe custom name for iib_property in Puppet realm. |
[object_name](#iib_property_object_name)         | This parameter specifies object_name of iib_property in Puppet realm.        |
[object_property](#iib_property_object_property) | This parameter specifies the object property you want to manage.             |
[provider](#iib_property_provider)               | resource.                                                                    |
[restart](#iib_property_restart)                 | applying the value and start again after the change has been applied.        |
[scope](#iib_property_scope)                     | This parameter specifies uniqe custom name for iib_property in Puppet realm. |
[set_value](#iib_property_set_value)             | This parameter specifies the value to set the specfied object property to.   |




### component<a name='iib_property_component'>

This parameter specifies the component of the IIB broker or server you
want to manage.


[Back to overview of iib_property](#attributes)


### name<a name='iib_property_name'>

This parameter specifies uniqe custom name for iib_property in Puppet realm.

In example

    'iib8/NODE1'


[Back to overview of iib_property](#attributes)


### object_name<a name='iib_property_object_name'>

This parameter specifies object_name of iib_property in Puppet realm.

In example

    'iib8/NODE1'


[Back to overview of iib_property](#attributes)


### object_property<a name='iib_property_object_property'>

This parameter specifies the object property you want to manage.

In example

    'iib8/NODE1'


[Back to overview of iib_property](#attributes)


### provider<a name='iib_property_provider'>

The specific backend to use for this `iib_property`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage different IIB node configurations


[Back to overview of iib_property](#attributes)


### restart<a name='iib_property_restart'>

Specfies if you want to automaticaly want to stop the broker or the server before
applying the value and start again after the change has been applied.

Valid values are `true`, `false`. 
[Back to overview of iib_property](#attributes)


### scope<a name='iib_property_scope'>

This parameter specifies uniqe custom name for iib_property in Puppet realm.


[Back to overview of iib_property](#attributes)


### set_value<a name='iib_property_set_value'>

This parameter specifies the value to set the specfied object property to.


[Back to overview of iib_property](#attributes)

