---
title: iib security profile
keywords: documentation
layout: documentation
sidebar: iib_config_sidebar
toc: false
---
## Overview

This resource allows you to manage Security Profile of node (broker) in an IBM
IIB realm.

Here is an example on how you should use this:

    iib_security_profile { '10.0.0.6/NODE/SECURITY_NAME':
      ensure                       => 'present',
      authentication               => 'NONE',
      authorization                => 'NONE',
      id_to_propagate_to_transport => 'Message ID',
      keystore                     => 'Reserved for future use',
      mapping                      => 'NONE',
      password_value               => 'PLAIN',
      propagation                  => 'TRUE',
      reject_blank_password        => 'FALSE',
      trust_store                  => 'Reserved for future use',
    }

## Attributes



Attribute Name                                                                     | Short Description                                                               |
---------------------------------------------------------------------------------- | ------------------------------------------------------------------------------- |
[authentication](#iib_security_profile_authentication)                             | Defines the type of authentication that is performed on the source identity.    |
[authentication_config](#iib_security_profile_authentication_config)               | and the information needed to look up the identity tokens.                      |
[authorization](#iib_security_profile_authorization)                               | identity.                                                                       |
[authorization_config](#iib_security_profile_authorization_config)                 | for membership).                                                                |
[broker](#iib_security_profile_broker)                                             | This parameter specifies custom name for iib_broker in IBM IIB realm.           |
[ensure](#iib_security_profile_ensure)                                             | The basic property that the resource should be in.                              |
[id_to_propagate_to_transport](#iib_security_profile_id_to_propagate_to_transport) | Enables the use of a specific security identity for propagation.                |
[instance](#iib_security_profile_instance)                                         | This shared parameter specifies iib_instance in IBM IIB realm.                  |
[keystore](#iib_security_profile_keystore)                                         | 
                                                                               |
[mapping](#iib_security_profile_mapping)                                           | Defines the type of mapping that is performed on the source identity.           |
[mapping_config](#iib_security_profile_mapping_config)                             | information required to look up the mapping routine.                            |
[name](#iib_security_profile_name)                                                 | This parameter specifies custom name for iib_security_profile in IBM IIB realm. |
[password_value](#iib_security_profile_password_value)                             | Defines how passwords are treated when they enter a message flow.               |
[propagation](#iib_security_profile_propagation)                                   | Enables or disables identity propagation on output and request nodes.           |
[provider](#iib_security_profile_provider)                                         | resource.                                                                       |
[reject_blank_password](#iib_security_profile_reject_blank_password)               | 
                                                                               |
[security_profile](#iib_security_profile_security_profile)                         | This parameter specifies custom name for iib_security_profile in IBM IIB realm. |
[transport_propagation_config](#iib_security_profile_transport_propagation_config) | is set to STATIC ID.                                                            |
[trust_store](#iib_security_profile_trust_store)                                   | 
                                                                               |




### authentication<a name='iib_security_profile_authentication'>

Defines the type of authentication that is performed on the source identity.
This property applies only to SecurityPEP nodes and input nodes. For more information,
see [Authentication and validation.](https://www.ibm.com/support/knowledgecenter/SSMKHH_10.0.0/com.ibm.etools.mft.doc/ap04020_.htm?view=kc)



[Back to overview of iib_security_profile](#attributes)

### authentication_config<a name='iib_security_profile_authentication_config'>

Defines the information that the integration node needs to connect to the provider,
and the information needed to look up the identity tokens. It is a provider-specific
configuration string. This property applies only to SecurityPEP nodes and input nodes.



[Back to overview of iib_security_profile](#attributes)

### authorization<a name='iib_security_profile_authorization'>

Defines the types of authorization checks that are performed on the mapped or source
identity. This property applies only to SecurityPEP nodes and input nodes. For more
information, see [Authorization](https://www.ibm.com/support/knowledgecenter/SSMKHH_10.0.0/com.ibm.etools.mft.doc/ap04040_.htm?view=kc).



[Back to overview of iib_security_profile](#attributes)

### authorization_config<a name='iib_security_profile_authorization_config'>

Defines how the integration node connects to the provider, and contains additional
information that can be used to check access (for example, a group that can be checked
for membership). It is a provider-specific configuration string. This property applies
only to SecurityPEP nodes and input nodes.



[Back to overview of iib_security_profile](#attributes)

### broker<a name='iib_security_profile_broker'>

This parameter specifies custom name for iib_broker in IBM IIB realm.

In example

    'NODE1'



[Back to overview of iib_security_profile](#attributes)

### ensure<a name='iib_security_profile_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of iib_security_profile](#attributes)

### id_to_propagate_to_transport<a name='iib_security_profile_id_to_propagate_to_transport'>

Enables the use of a specific security identity for propagation. Set the value to
STATIC ID, and set the security identity by using the transportPropagationConfig
parameter.



[Back to overview of iib_security_profile](#attributes)

### instance<a name='iib_security_profile_instance'>

This shared parameter specifies iib_instance in IBM IIB realm.

Example name

    'iib8'



[Back to overview of iib_security_profile](#attributes)

### keystore<a name='iib_security_profile_keystore'>





[Back to overview of iib_security_profile](#attributes)

### mapping<a name='iib_security_profile_mapping'>

Defines the type of mapping that is performed on the source identity. This property
applies only to SecurityPEP nodes and input nodes. For more information, see
[Identity mapping](https://www.ibm.com/support/knowledgecenter/SSMKHH_10.0.0/com.ibm.etools.mft.doc/ap04030_.htm?view=kc).



[Back to overview of iib_security_profile](#attributes)

### mapping_config<a name='iib_security_profile_mapping_config'>

Defines how the integration node connects to the provider, and contains additional
information required to look up the mapping routine. It is a provider-specific configuration
string. This property applies only to SecurityPEP nodes and input nodes.



[Back to overview of iib_security_profile](#attributes)

### name<a name='iib_security_profile_name'>

This parameter specifies custom name for iib_security_profile in IBM IIB realm.

In example

    'iib8/NODE1/PROFILE_1'



[Back to overview of iib_security_profile](#attributes)

### password_value<a name='iib_security_profile_password_value'>

Defines how passwords are treated when they enter a message flow. If PLAIN is selected,
the password appears in the Properties folder in plain text. If OBFUSCATE is selected,
the password appears in the Properties folder in base64 encoding. If MASK is selected,
the password appears in the Properties folder as four asterisks (****). This property
applies only to SecurityPEP nodes and input nodes.



[Back to overview of iib_security_profile](#attributes)

### propagation<a name='iib_security_profile_propagation'>

Enables or disables identity propagation on output and request nodes. On the security
enabled input nodes, you can choose to select only identity propagation, without specifying
any other security operations, to make the extracted incoming identity or security token
available for use in the other nodes in the message flow, such as output or request nodes.
For more information, see [Identity and security token propagation](https://www.ibm.com/support/knowledgecenter/SSMKHH_10.0.0/com.ibm.etools.mft.doc/ap04050_.htm?view=kc).



[Back to overview of iib_security_profile](#attributes)

### provider<a name='iib_security_profile_provider'>

The specific backend to use for this `iib_security_profile`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage different IIB Broker Security Profiles.



[Back to overview of iib_security_profile](#attributes)

### reject_blank_password<a name='iib_security_profile_reject_blank_password'>





[Back to overview of iib_security_profile](#attributes)

### security_profile<a name='iib_security_profile_security_profile'>

This parameter specifies custom name for iib_security_profile in IBM IIB realm.

In example

    'PROFILE_1'



[Back to overview of iib_security_profile](#attributes)

### transport_propagation_config<a name='iib_security_profile_transport_propagation_config'>

Provides a specific security identity to propagate when idToPropagateToTransport
is set to STATIC ID. Set the value to the name that you associate with the static
user name and password identity when you run the mqsisetdbparms. For more information,
see [Configuring a message flow for identity propagation](https://www.ibm.com/support/knowledgecenter/SSMKHH_10.0.0/com.ibm.etools.mft.doc/ap04160_.htm?view=kc).



[Back to overview of iib_security_profile](#attributes)

### trust_store<a name='iib_security_profile_trust_store'>





[Back to overview of iib_security_profile](#attributes)
