#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:function_level,
            :parent => Puppet_X::EnterpriseModules::Iib::BrokerGlobalProperty) do
  include EasyType
  include Puppet_X::EnterpriseModules::Iib::Commands

  defaultto 'all'

  desc <<-DOC
This property allows you to manage the function level of iib broker in an IBM IIB realm.

A change in this property can only be done by stopping the broker. By default puppet
will not do this and issue a warning. When you want to apply this value anyway, use
the `auto_restart` parameter and set it to`true`.

Here is an example on how you should use this:

    iib_broker { 'iib8/NODE1':
      ...
      function_level => '10.0.0.7',
      auto_restart   =>  true,
      ...
    }

In this example you a change the function levelof the IIB broker to IIB version
10.0.0.7.

Valid values

- string

  DOC

  data_type('Optional[String]')

  # The function level cannot be applied on creation but must be specfied
  # after creation on a stopped broker
  on_create do
    nil
  end

  after_create do
    if ace_used?(resource[:instance])
      return Puppet.notice "mqsichangebroker is not supported with  " \
                           "IBM ACE #{resource[:instance]}"
    end

    mqsichangebroker("#{resource[:broker]} -f #{value}", { :instance => resource[:instance] })
  end

  maps_to('function level')
end
