#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:https_connector_enable_lookups,
            :parent => Puppet_X::EnterpriseModules::Iib::BrokerSharedProperty) do
  include EasyType
  include Puppet_X::EnterpriseModules::Iib::Commands

  desc <<-DOC
This property allows you to manage HTTPSConnector enableLookups of iib_broker in an IBM IIB realm.

Here is an example on how you should use this:

    iib_broker { '10.0.0.9/NODE1':
      ensure                         => 'present',
      https_connector_enable_lookups => 'true',
      status                         => 'running',
    }

In this example you are ensuring that server is present. Then change property
enableLookups of IBM IIB broker HTTPSConnector to true. After that you are
ensuring that broker is running.

Initial value

- false

Valid values

- true
- false

  DOC

  newvalues('true', 'false')

  data_type('Optional[Boolean]')

  to_translate_to_resource do |raw_resource|
    value = raw_resource[:shared_properties_output]['HTTPSConnector']
    return nil unless value
    value.scan(/enableLookups\=\'([^\']*)\'/).flatten.first
  end

  maps_to('HTTPSConnector', 'enableLookups')
end
