#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:status) do
  include EasyType
  include Puppet_X::EnterpriseModules::Iib::Commands

  desc <<-DOC
The status of the IIB node. Can either be `running` or `stopped`.

Here is an example on how to use this:

    iib_node {...
      ...
      status => 'running',
      ...
    }

  DOC

  defaultto 'running'

  data_type "Enum['stopped', 'running']"

  newvalues 'stopped', 'running'

  after_create do
    case value.to_sym
    when :running
      Puppet.debug "Starting broker #{resource.broker}"
      mqsistart(resource.broker, { :instance => resource.instance })
    when :stopped
      return nil
    else
      fail 'internal error. Invalid status value.'
    end
  end

  on_modify do
    case value.to_sym
    when :running
      Puppet.debug "Starting broker #{resource.broker}"
      mqsistart(resource.broker, { :instance => resource.instance })
    when :stopped
      Puppet.debug "Stopping broker #{resource.broker}"
      mqsistop(resource.broker, { :instance => resource.instance })
    else
      fail 'internal error. Invalid status value.'
    end
  end

  to_translate_to_resource do |raw_resource|
    raw_resource[:status]
  end
end
