#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent.parent.parent + 'easy_type' + 'lib')
require 'easy_type'
require 'puppet_x/enterprisemodules/iib/commands'
require 'puppet_x/enterprisemodules/iib/settings'
require 'puppet_x/enterprisemodules/iib/server_property'
require 'puppet_x/enterprisemodules/iib/server_array_property'
require 'puppet_x/enterprisemodules/iib/server_info'

Puppet::Type.newtype(:iib_credential) do
  include EasyType
  include Puppet_X::EnterpriseModules::Iib::Commands
  include Puppet_X::EnterpriseModules::Iib::Settings
  extend  Puppet_X::EnterpriseModules::Iib::ServerInfo

  def self.module_name; 'iib_config'; end

  index_regexp = /Integration server '(\S+)' on integration node '(\S+)' is (\S+)\./

  desc <<-DOC
This resource allows you to manage dbparams (e.g. credentials) in IBM IIB realm.

Here is an example on how you should use this:

    iib_credential { 'IIB107/ldap::myad.example.com':
      ensure   => 'present',
      username => 'myusername',
      password => 'extremlysecret',
    }

  DOC

  ensurable

  map_titles_to_attributes([%r{((.*)\/(.*)\/(.*))}, [:name, :instance, :broker, :resource_name]])

  validate do
    return if self.ensure == :absent
    fail 'You need to specfy the username' if username.nil? or username == ''
    fail 'You need to specfy the password' if password.nil? or password == ''
  end

  to_get_raw_resources do
    fail "iib_credential doesn't support the instances method."
  end

  on_prefetch do | resources, provider|
    resources.each do |name, _value|
      instance, broker,resource_name = name.split('/')
      output = mqsireportdbparms("#{broker} -n #{resource_name}", { :instance => instance })
      next if output =~ /BIP8208W: No resources found with resource name/
      # Resource found
      value = provider.map_raw_to_resource({:name => name,
                                                              :ensure => :present,
                                                              :instance => instance,
                                                              :broker => broker,
                                                              :resource_name => resource_name,
                                                              :output => output})
      resources[name].provider = value if value.name == name
    end
  end

  on_create do
    apply
  end

  on_modify do
    apply
  end

  on_destroy do
    [:mqsisetdbparms, "#{broker} -n #{resource_name} -d", { :instance => instance }]
  end

  parameter :name
  parameter :broker
  parameter :instance
  parameter :resource_name

  property  :username
  property  :password

  def apply
    command = "#{broker} -n #{resource_name} -u '#{username}'"
    command << " -p '#{password}'" if password
    [:mqsisetdbparms, command, { :instance => instance }]
  end

end
