#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent.parent.parent + 'easy_type' + 'lib')
require 'easy_type'
require 'puppet_x/enterprisemodules/iib/access'
require 'puppet_x/enterprisemodules/iib/ace_check'
require 'puppet_x/enterprisemodules/iib/commands'
require 'puppet_x/enterprisemodules/iib/settings'

Puppet::Type.newtype(:iib_deployment) do
  include EasyType
  include Puppet_X::EnterpriseModules::Iib::Access
  include Puppet_X::EnterpriseModules::Iib::AceCheck
  include Puppet_X::EnterpriseModules::Iib::Commands
  include Puppet_X::EnterpriseModules::Iib::Settings

  def self.module_name; 'iib_config'; end

  index_regexp = /Application '(\S+)' on integration server '(\S+)' is (\S+)\.\s*\n\nDeployed: '.+' in Bar file '(\S+)'/

  desc <<-DOC
This resource allows you to manage process of deployment of IBM IIB.

Here is an example on how you should use this:

    iib_deployment { 'IIB107/IB10NODE1/server_2/Hello':
      ensure => 'present',
      source => '/tmp/Helloproject.TestMode.bar',
    }

In this example you are ensuring that deployment is done from provided source.

  DOC

  map_titles_to_attributes([%r{(((.*)\/(.*))\/(.*)\/(.*))}, [:name, :broker, :instance, :deployment_name, :server, :application]])

  ensurable

  to_get_raw_resources do
    Puppet.debug 'Getting raw resources for iib_deployents'
    iib_deployments = []
    configuration.keys.collect do |iib_instance|
      Puppet.debug "index of #{iib_instance}"
      iib_brokers(iib_instance).each do |broker|
        iib_servers(broker, iib_instance).each do |server|
          list = mqsilist("#{broker} -e #{server} -rd2", { :instance => iib_instance }).scan(index_regexp).collect { |e| e.push(broker, iib_instance) }.flatten
          iib_deployments << list if list.any?
        end
      end
    end
    iib_deployments.collect { |e| Hash[[:application, :server, :status, :source, :broker, :instance].zip(e)] }
  end

  on_create do
    [:mqsideploy, "#{deployment_name} -e #{server} -a #{source}", { :instance => instance }]
  end

  on_modify do
    # delegate to the properties
  end

  on_destroy do
    [:mqsideploy, "#{deployment_name} -e #{server} -d #{application}", { :instance => instance }]
  end

  parameter :name
  parameter :broker
  parameter :deployment_name
  parameter :server
  parameter :application
  parameter :instance

  property :source # Readonly

  autorequire(:file) { source }
end
