#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:source) do
  include EasyType

  desc <<-DOC
This property is the bar file for deployment.

The deployment process will run with the identity of the `iibadmin` user.
Makes sure the file is accessible by the `iibadmin` user.

    iib_deployment { 'IIB107/IB10NODE1/server_2/Hello':
      ensure => 'present',
      source => '/tmp/Helloproject.TestMode.bar',
    }

  DOC

  data_type('Optional[String]')

  munge { |value| File.expand_path(value) }

  def insync?(is)
    fail "#{path}: file not found #{should}." unless File.exist?(should)

    is == should
  end

  to_translate_to_resource do |raw_resource|
    raw_resource[:source]
  end

  on_modify do
    Puppet.warning "#{path}: Source property is readonly"
  end
end
