
#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent.parent.parent + 'easy_type' + 'lib')
require 'easy_type'
require 'puppet_x/enterprisemodules/iib/commands'
require 'puppet_x/enterprisemodules/iib/settings'
require 'puppet_x/enterprisemodules/iib/security_profile_info'
require 'puppet_x/enterprisemodules/iib/security_profile_property'
require 'puppet_x/enterprisemodules/iib/security_profile_boolean_property'

Puppet::Type.newtype(:iib_security_profile) do
  include EasyType
  include Puppet_X::EnterpriseModules::Iib::Commands
  include Puppet_X::EnterpriseModules::Iib::Settings
  extend  Puppet_X::EnterpriseModules::Iib::SecurityProfileInfo

  def self.module_name
    'iib_config'
  end

  desc <<-DOC
This resource allows you to manage Security Profile of node (broker) in an IBM
IIB realm.

Here is an example on how you should use this:

    iib_security_profile { '10.0.0.6/NODE/SECURITY_NAME':
      ensure                       => 'present',
      authentication               => 'NONE',
      authorization                => 'NONE',
      id_to_propagate_to_transport => 'Message ID',
      keystore                     => 'Reserved for future use',
      mapping                      => 'NONE',
      password_value               => 'PLAIN',
      propagation                  => true,
      reject_blank_password        => false,
      trust_store                  => 'Reserved for future use',
    }

  DOC

  broker_regexp = /.*Integration node '(\S+)'(?: .*?queue manager '(\S+?)')? .*?(?:administration URI '(.\S+?)' )?is (\S*)\s*\./
  index_regexp  = /((?:\v*)\S+(?:\v*(?:\n)))+/

  ensurable

  map_titles_to_attributes([%r{((.*)\/(.*)\/(.*))}, [:name, :instance, :broker, :security_profile]])

  to_get_raw_resources do
    Puppet.debug 'Getting raw resources for iib_execution_path'
    configuration.keys.collect do |iib_instance|
      Puppet.debug "index of #{iib_instance}"
      broker_information   = mqsilist('-a -r', { :instance => iib_instance }).scan(broker_regexp)
      broker               = broker_information.flatten.first
      security_output      = mqsireportproperties("#{broker} -c SecurityProfiles -o AllReportableEntityNames -a", instance: iib_instance)
      Puppet.debug security_output
      security_information = security_output.scan(index_regexp).flatten
      return [] if security_information.empty?

      information = security_information[2..-1].map(&:strip).map do |element|
        mqsi_output = properties_output(broker, element, iib_instance)
        [element, broker, iib_instance, mqsi_output]
      end

      information.collect { |e| Hash[[:security_profile, :broker, :instance, :output].zip(e)] }
    end.flatten
  end

  on_create do
    mqsicreateconfigurableservice("#{broker} -c SecurityProfiles -o #{security_profile}", { :instance => instance })
    # mqsicreateconfigurableservice IN_MIBE3AA01 -c SecurityProfiles -o MIB_e2e6_HRPeople_All2 -n mapping,rejectBlankpassword,propagation,passwordValue,keyStore,authorizationConfig,authenticationConfig,idToPropagateToTransport,trustStore,authentication,authorization,mappingConfig,transportPropagationConfig -v "NONE","FALSE","TRUE","PLAIN","Reserved for future use",\"ldap://ad.moodys.net:389/CN=mib_e2e6_hrpeople,OU=SecGroups,OU=SERVICE,DC=ad,DC=moodys,DC=net\",\"ldap://ad.moodys.net:389/DC=ad,DC=moodys,DC=net?sAMAccountName\","Message ID","Reserved for future use","LDAP","LDAP","",""
  end

  on_modify do
    # Delegate to the properties
  end

  on_destroy do
    [:mqsideleteconfigurableservice, "#{broker} -c SecurityProfiles -o #{security_profile}", { :instance => instance }]
  end

  # Uncomment output to see whole attribute string used for separate attributes.
  # property :output

  parameter :name
  parameter :broker
  parameter :instance
  parameter :security_profile

  property  :authentication_config
  property  :authentication
  property  :authorization_config
  property  :authorization
  property  :id_to_propagate_to_transport
  property  :keystore
  property  :mapping_config
  property  :mapping
  property  :password_value
  property  :propagation
  property  :reject_blank_password
  property  :transport_propagation_config
  property  :trust_store
end
