#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:propagation,
            parent:  Puppet_X::EnterpriseModules::Iib::SecurityProfileBooleanProperty) do
  include Puppet_X::EnterpriseModules::Iib::Commands

  desc <<-DOC
Enables or disables identity propagation on output and request nodes. On the security
enabled input nodes, you can choose to select only identity propagation, without specifying
any other security operations, to make the extracted incoming identity or security token
available for use in the other nodes in the message flow, such as output or request nodes.
For more information, see [Identity and security token propagation](https://www.ibm.com/support/knowledgecenter/SSMKHH_10.0.0/com.ibm.etools.mft.doc/ap04050_.htm?view=kc).

Here is how to do it:

    iib_security_profile { '10.0.0.6/NODE/Default_Propagation':
      ensure             => 'present',
      propagation        => true,
    }

  DOC

  data_type('Optional[Boolean]')

  maps_to('propagation')

  newvalues(:true, :false)
  aliasvalue('TRUE', :true)
  aliasvalue('FALSE', :false)
end
