#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent.parent.parent + 'easy_type' + 'lib')
require 'easy_type'
require 'puppet_x/enterprisemodules/iib/ace_check'
require 'puppet_x/enterprisemodules/iib/commands'
require 'puppet_x/enterprisemodules/iib/server_array_property'
require 'puppet_x/enterprisemodules/iib/server_info'
require 'puppet_x/enterprisemodules/iib/server_property'
require 'puppet_x/enterprisemodules/iib/settings'

Puppet::Type.newtype(:iib_server) do
  include EasyType
  include Puppet_X::EnterpriseModules::Iib::Commands
  include Puppet_X::EnterpriseModules::Iib::Settings
  extend  Puppet_X::EnterpriseModules::Iib::ServerInfo
  extend  Puppet_X::EnterpriseModules::Iib::AceCheck

  def self.module_name; 'iib_config'; end

  broker_regexp = /.*Integration node '(\S+)'(?: .*?queue manager '(\S+?)')? .*?(?:administration URI '(.\S+?)' )?is (\S*)\s*\./
  index_regexp = /Integration server '(\S+)' on integration node '(\S+)' is (\S+)\./

  desc <<-DOC
This resource allows you to manage server in an IBM IIB realm.

Here is an example on how you should use this:

    iib_server { 'IIB107/IB10NODE1/server_1':
      ensure => 'present',
      status => 'running',
    }

In this example you are ensuring that server is running. If the server is
stopped the resource starts server, if absent the new server is created.

  DOC

  ensurable

  map_titles_to_attributes([%r{((.*)\/(.*)\/(.*))}, [:name, :instance, :broker, :server]])

  to_get_raw_resources do
    Puppet.debug 'Getting raw resources for iib_execution_path'
    configuration.keys.collect do |iib_instance|
      Puppet.debug "index of #{iib_instance}"

      if ace_used?(iib_instance)
        brokers = mqsilist('-a -r', { :instance => iib_instance }).scan(broker_regexp).map(&:first)
        information = brokers.map do |broker|
          mqsilist("-a -r #{broker}", { :instance => iib_instance }).scan(index_regexp)
        end.reduce(:+)
      else
        information = mqsilist('-a -r', { :instance => iib_instance }).scan(index_regexp)
      end

      information.map do |element|
        element << iib_instance
        element << properties_output(element, iib_instance)
      end

      information.collect { |e| Hash[[:server, :broker, :status, :instance, :output].zip(e)] }
    end.flatten
  end

  on_create do
    mqsicreateexecutiongroup("#{broker} -e #{server}", { :instance => instance })
  end

  on_modify do
    # Delegate to the properties
  end

  on_destroy do
    [:mqsideleteexecutiongroup, "#{broker} -e #{server}", { :instance => instance }]
  end

  # Uncomment output to see whole attribute string used for separate attributes.
  # property  :output

  parameter :name
  parameter :broker
  parameter :instance
  parameter :server
  property  :status

  property  :callable_flow_manager_delay_reply_until_flow_commit
  property  :callable_flow_manager_disable_remote_input_registration
  property  :callable_flow_manager_redeploy_message_timeout
  property  :callable_flow_manager_remote_retry_timeout
  property  :callable_flow_manager_retry_local_during_deploy
  property  :callable_flow_manager_retry_remote_until_timeout

  property  :connectors_shared_idle_timeout

  property  :execution_group_http_nodes_embedded_listener
  property  :execution_group_injection_mode
  property  :execution_group_soap_nodes_embedded_listener
  property  :execution_group_trace_level

  property  :http_connector_accept_count
  property  :http_connector_auto_respond_http_head_requests
  property  :http_connector_compressable_mime_types
  property  :http_connector_compression
  property  :http_connector_connection_linger
  property  :http_connector_connection_timeout
  property  :http_connector_cors_allow_credentials
  property  :http_connector_cors_allow_headers
  property  :http_connector_cors_allow_methods
  property  :http_connector_cors_allow_origins
  property  :http_connector_cors_enabled
  property  :http_connector_cors_expose_headers
  property  :http_connector_cors_max_age
  property  :http_connector_enable_lookups
  property  :http_connector_max_http_header_size
  property  :http_connector_max_keep_alive_requests
  property  :http_connector_max_posts_size
  property  :http_connector_max_threads
  property  :http_connector_min_spare_threads
  property  :http_connector_no_compression_user_agents
  property  :http_connector_port
  property  :http_connector_restricted_user_area
  property  :http_connector_server_name
  property  :http_connector_socket_buffer
  property  :http_connector_tcp_no_delay
  property  :http_connector_timeout
  property  :http_connector_user_trace_level

  property  :https_connector_accept_count
  property  :https_connector_algorithm
  property  :https_connector_auto_respond_http_head_requests
  property  :https_connector_client_auth
  property  :https_connector_compressable_mime_types
  property  :https_connector_compression
  property  :https_connector_connection_linger
  property  :https_connector_connection_timeout
  property  :https_connector_cors_allow_credentials
  property  :https_connector_cors_allow_headers
  property  :https_connector_cors_allow_methods
  property  :https_connector_cors_allow_origins
  property  :https_connector_cors_enabled
  property  :https_connector_cors_expose_headers
  property  :https_connector_cors_max_age
  property  :https_connector_enable_lookups
  property  :https_connector_key_alias
  property  :https_connector_keypass
  property  :https_connector_keystore_file
  property  :https_connector_keystore_password
  property  :https_connector_keystore_type
  property  :https_connector_max_http_header_size
  property  :https_connector_max_keep_alive_requests
  property  :https_connector_max_posts_size
  property  :https_connector_max_threads
  property  :https_connector_min_spare_threads
  property  :https_connector_no_compression_user_agents
  property  :https_connector_port
  property  :https_connector_restricted_user_area
  property  :https_connector_server_name
  property  :https_connector_session_cache_size
  property  :https_connector_socket_buffer
  property  :https_connector_ssl_protocol
  property  :https_connector_tcp_no_delay
  property  :https_connector_timeout
  property  :https_connector_truststore_file
  property  :https_connector_truststore_password
  property  :https_connector_truststore_type
  property  :https_connector_user_trace_level

  property  :rest_resource_stats_reporting_on

  #
  # Currently not supported properties
  #
  # property  :execution_group_trace_filter
  # property  :execution_group_user_trace_filter
end
