#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:http_connector_compressable_mime_types,
            :array_matching => :all,
            :parent => Puppet_X::EnterpriseModules::Iib::ServerArrayProperty) do

  include EasyType
  include EasyType::ArrayProperty
  include Puppet_X::EnterpriseModules::Iib::Commands

  desc <<-DOC
This property allows you to manage HTTPConnector compressableMimeTypes of iib_server in an IBM IIB realm.

Here is an example on how you should use this:

    iib_server { 'iib8/NODE1/server_1':
      ensure                                 => 'present',
      http_connector_compressable_mime_types => ['text/html'],
      status                                 => 'running',
    }

In this example you are ensuring that server is present.
Then change property HTTPConnector compressableMimeTypes of IBM IIB server only to text/html.
After that you are ensuring that server is running.

Here is a second example on how you should use this with array values:

    iib_server { 'iib8/NODE1/server_1':
      ensure                                 => 'present',
      http_connector_compressable_mime_types => ['text/html', 'text/xml', 'text/plain'],
      status                                 => 'running',
    }

In this example you are ensuring that server is present.
Then change property HTTPConnector compressableMimeTypes of IBM IIB server only to text/html,text/xml,text/plain.
After that you are ensuring that server is running.

Valid values

- text/html
- text/xml
- text/plain
- text/css
- application/javascript
- image/gif
- image/png
- application/json

  DOC

  data_type('Array[Optional[String]]')

  maps_to('HTTPConnector', 'compressableMimeTypes')
end
