#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:http_connector_cors_allow_headers,
            :array_matching => :all,
            :parent => Puppet_X::EnterpriseModules::Iib::ServerArrayProperty) do

  include EasyType
  include EasyType::ArrayProperty
  include Puppet_X::EnterpriseModules::Iib::Commands

  desc <<-DOC
This property allows you to manage HTTPConnector corsAllowHeaders of iib_server in an IBM IIB realm.

Here is an example on how you should use this:

    iib_server { 'iib8/NODE1/server_1':
      ensure                            => 'present',
      http_connector_cors_allow_headers => ['Accept'],
      status                            => 'running',
    }

In this example you are ensuring that server is present. Then change property
HTTPConnector corsAllowHeaders of IBM IIB server only to Accept. After that you
are ensuring that server is running.

Here is a second example on how you should use this with array values:

    iib_server { 'iib8/NODE1/server_1':
      ensure                            => 'present',
      http_connector_cors_allow_headers => ['Accept', 'Accept-Language', 'Content-Language', 'Content-Type'],
      status                            => 'running',
    }

In this example you are ensuring that server is present. Then change property
HTTPConnector corsAllowHeaders of IBM IIB server only to X-Header1, X-Header2,
X-Header3 After that you are ensuring that server is running.

Valid values

- list

  DOC

  data_type('Array[Optional[String]]')

  maps_to('HTTPConnector', 'corsAllowHeaders')
  yaml_maps_to('ResourceManagers', 'HTTPConnector', 'CORSAllowHeaders')
end
