#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:http_connector_cors_allow_methods,
            :array_matching => :all,
            :parent => Puppet_X::EnterpriseModules::Iib::ServerArrayProperty) do

  include EasyType
  include EasyType::ArrayProperty
  include Puppet_X::EnterpriseModules::Iib::Commands

  desc <<-DOC
This property allows you to manage HTTPConnector corsAllowMethods of iib_server in an IBM IIB realm.

Here is an example on how you should use this:

    iib_server { 'iib8/NODE1/server_1':
      ensure                            => 'present',
      http_connector_cors_allow_methods => ['GET'],
      status                            => 'running',
    }

In this example you are ensuring that server is present. Then change property
HTTPConnector corsAllowMethods of IBM IIB server only to GET. After that you are
ensuring that server is running.

Here is a second example on how you should use this with array values:

    iib_server { 'iib8/NODE1/server_1':
      ensure                            => 'present',
      http_connector_cors_allow_methods => ['GET','HEAD','POST','PUT','PATCH','DELETE','OPTIONS'],
      status                            => 'running',
    }

In this example you are ensuring that server is present. Then change property
HTTPConnector corsAllowMethods of IBM IIB server to
GET,HEAD,POST,PUT,PATCH,DELETE,OPTIONS. After that you are ensuring that server
is running.

Valid values

- list

  DOC

  data_type('Array[Optional[String]]')

  maps_to('HTTPConnector', 'corsAllowMethods')
  yaml_maps_to('ResourceManagers', 'HTTPConnector', 'CORSAllowMethods')
end
