#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:http_connector_cors_max_age,
            :parent => Puppet_X::EnterpriseModules::Iib::ServerProperty) do
  include EasyType
  include EasyType::Validators::Integer
  include Puppet_X::EnterpriseModules::Iib::Commands

  desc <<-DOC
This property allows you to manage HTTPConnector corsMaxAge of iib_server in an IBM IIB realm.

Here is an example on how you should use this:

    iib_server { 'iib8/NODE1/server_1':
      ensure                      => 'present',
      http_connector_cors_max_age => '-1',
      status                      => 'running',
    }

In this example you are ensuring that server is present. Then change property
HTTPConnector corsMaxAge of IBM IIB server to -1 remove max age header from
response. After that you are ensuring that server is running.

Here is second example on how you should use this:

    iib_server { 'iib8/NODE1/server_1':
      ensure                      => 'present',
      http_connector_cors_max_age => '1000',
      status                      => 'running',
    }

In this example you are ensuring that server is present. Then change property
HTTPConnector corsMaxAge of IBM IIB server to 1000 seconds. After that you are
ensuring that server is running.

Valid values

    - integer

  DOC

  data_type('Optional[Integer]')

  maps_to('HTTPConnector', 'corsMaxAge')
  yaml_maps_to('ResourceManagers', 'HTTPConnector', 'CORSMaxAge')

end
