#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:https_connector_algorithm,
            :parent => Puppet_X::EnterpriseModules::Iib::ServerProperty) do
  include EasyType
  include Puppet_X::EnterpriseModules::Iib::Commands

  desc <<-DOC
This property allows you to manage HTTPSConnector algorithm of iib_server in an IBM IIB trace.

Here is an example on how you should use this:

    iib_server { 'iib8/NODE1/server_1':
      ensure                    => 'present',
      https_connector_algorithm => 'SunX509',
      status                    => 'running',
    }

In this example you are ensuring that server is present. Then change property
algorithm of IBM IIB server HTTPSConnector to `SunX509` milliseconds. At
the you are ensuring that server is running.

Valid values

- `SunX509` (Solaris and HP-UX)
- `IbmX509` (AIX(c), Linux, Windows, z/OS(c))

  DOC

  newvalues('SunX509', 'IbmX509')

  data_type("Optional[Enum['SunX509', 'IbmX509']]")

  maps_to('HTTPSConnector', 'algorithm')
end
