#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:https_connector_ciphers,
            :array_matching => :all,
            :parent => Puppet_X::EnterpriseModules::Iib::ServerArrayProperty) do

  include EasyType
  include EasyType::ArrayProperty
  include Puppet_X::EnterpriseModules::Iib::Commands

  desc <<-DOC
This property allows you to manage HTTPSConnector ciphers of iib_server in an IBM IIB realm.

Here is an example on how you should use this:

    iib_server { 'iib8/NODE1/server_1':
      ensure                  => 'present',
      https_connector_ciphers => [''],
      status                  => 'running',
    }

In this example you are ensuring that server is present. Then change property
ciphers of IBM IIB server HTTPSConnector only to null. After that you
are ensuring that server is running.


Here is a second example on how you should use this with array values:

    iib_server { 'iib8/NODE1/server_1':
      ensure                  => 'present',
      https_connector_ciphers => ['Cipher-1','Cipher-2','Cipher-3'],
      status                  => 'running',
    }

In this example you are ensuring that server is present. Then change property
ciphers of IBM IIB server HTTPSConnector only to Cipher1, Cipher2,
Cipher3 After that you are ensuring that server is running.


Valid values

    - list

  DOC

  data_type('Array[Optional[String]]')

  maps_to('HTTPSConnector', 'ciphers')
end
