#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:https_connector_cors_allow_origins,
            :array_matching => :all,
            :parent => Puppet_X::EnterpriseModules::Iib::ServerArrayProperty) do
  include EasyType
  include EasyType::ArrayProperty
  include Puppet_X::EnterpriseModules::Iib::Commands

  desc <<-DOC
This property allows you to manage HTTPSConnector corsAllowOrigins of iib_server in an IBM IIB realm.

Here is an example on how you should use this:

    iib_server { 'iib8/NODE1/server_1':
      ensure                            => 'present',
      https_connector_cors_allow_origins => ['*'],
      status                            => 'running',
    }

In this example you are ensuring that server is present. Then change property
HTTPSConnector corsAllowOrigins of IBM IIB server only to all. After that you
are ensuring that server is running.

Here is a second example on how you should use this with array values:

    iib_server { 'iib8/NODE1/server_1':
      ensure                             => 'present',
      https_connector_cors_allow_origins => ['https://www.example.com','https://www.example.com':7843,'https://othersite.net:7800'],
      status                             => 'running',
    }

In this example you are ensuring that server is present. Then change property
HTTPSConnector corsAllowOrigins of IBM IIB server only to
http://www.example.com, https://www.example.com:7843, http://othersite.net:7800.
After that you are ensuring that server is running.


Valid values

- list

  DOC

  data_type('Array[Optional[String]]')

  maps_to('HTTPSConnector', 'corsAllowOrigins')
  yaml_maps_to('ResourceManagers', 'HTTPSConnector', 'CORSAllowOrigins')
end
