#
# See the file "LICENSE" for the full license governing this code.
#

#
# Module used for lookups in nested keys "Hash of Hashes" and
# recursive setup of the value in nested hash which we don't now is there during
# creation.
#
module HashAndArrayToolkit
  #
  # Look recursively for value in hash
  #
  def search(key, *next_keys)
    value = self[key]
    return value if value.nil? || next_keys.empty?
    return value.search(*next_keys) if value.respond_to?(:search)
  end

  #
  # Sets recursively for value in nested hash
  #
  def set(value, key, *next_keys)
    if next_keys.empty?
      self[key] = value
      return value
    end

    modified_hash = self[key]
    self[key] = {} if modified_hash.nil?

    return modified_hash.set(value, *next_keys) if modified_hash.respond_to?(:set)
  end
end

# Include method to be accesible in array and hash via monkey patch.
class Hash; include HashAndArrayToolkit; end
class Array; include HashAndArrayToolkit; end
